@@ -34,6 +34,8 @@ def read_program(program, args=None):
     global spec, opcodes
     intcblock_opcode = 32
     bytecblock_opcode = 38
+    pushbytes_opcode = 128
+    pushint_opcode = 129
 
     if not program:
         raise error.InvalidProgram("empty program")
@@ -76,10 +78,20 @@ def read_program(program, args=None):
         size = op['Size']
         if size == 0:
             if op['Opcode'] == intcblock_opcode:
-                size_inc, ints = read_int_const_block(program, pc)
+                size_inc, found_ints = read_int_const_block(program, pc)
+                ints += found_ints
                 size += size_inc
             elif op['Opcode'] == bytecblock_opcode:
-                size_inc, bytearrays = read_byte_const_block(program, pc)
+                size_inc, found_bytearrays = read_byte_const_block(program, pc)
+                bytearrays += found_bytearrays
+                size += size_inc
+            elif op['Opcode'] == pushint_opcode:
+                size_inc, found_int = read_push_int_block(program, pc)
+                ints.append(found_int)
+                size += size_inc
+            elif op['Opcode'] == pushbytes_opcode:
+                size_inc, found_bytearray = read_push_byte_block(program, pc)
+                bytearrays.append(found_bytearray)
                 size += size_inc
             else:
                 raise error.InvalidProgram("invalid instruction")
@@ -137,12 +149,41 @@ def read_byte_const_block(program, pc):
             raise error.InvalidProgram(
                 "could not decode []byte const[%d] at pc=%d" % (i, pc + size))
         size += bytes_used
-        if pc + size >= len(program):
+        if pc + size + item_len > len(program):
             raise error.InvalidProgram("bytecblock ran past end of program")
         bytearrays.append(program[pc+size:pc+size+item_len])
         size += item_len
     return size, bytearrays
 
+def check_push_int_block(program, pc):
+    size, _ = read_push_int_block(program, pc)
+    return size
+
+def read_push_int_block(program, pc):
+    size = 1
+    single_int, bytes_used = parse_uvarint(program[pc + size:])
+    if bytes_used <= 0:
+        raise error.InvalidProgram(
+            "could not decode push int const at pc=%d" % (pc + size))
+    size += bytes_used
+    return size, single_int
+
+def check_push_byte_block(program, pc):
+    size, _ = read_push_byte_block(program, pc)
+    return size
+
+def read_push_byte_block(program, pc):
+    size = 1
+    item_len, bytes_used = parse_uvarint(program[pc + size:])
+    if bytes_used <= 0:
+        raise error.InvalidProgram(
+            "could not decode push []byte const size at pc=%d" % (pc + size))
+    size += bytes_used
+    if pc + size + item_len > len(program):
+        raise error.InvalidProgram("pushbytes ran past end of program")
+    single_bytearray = program[pc+size:pc+size+item_len]
+    size += item_len
+    return size, single_bytearray
 
 def parse_uvarint(buf):
     x = 0
